/* 故障报修
 * @Author: Li Hanlin
 * @Date: 2022-12-02 11:41:03
 * @Last Modified by: Li Hanlin
 * @Last Modified time: 2023-02-10 17:58:21
 */

import * as React from 'react';
import { useState, useMemo, useRef } from 'react';
import DrawerPro from '@/components/DrawerPro';
import AutoTable from '@/components/AutoTable';
import FormTable from "@/components/AutoTable/mtable";
import PremButton from '@/components/PremButton';
import getcolumns from './columns';
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
import Addform from '@/components/Addform';
import Detail from '@/components/RepaireDetail/Detail';
import dayjs from 'dayjs';
function Contract(props) {
  let actionRef = useRef(),
    formRef = useRef();
  const [drawer, setdrawer] = useState({
    open: false,
  }),
    [activeTabKey, setactiveTabKey] = useState('1'),
    [amount, camount] = useState(0);

  const { run, loading } = useRequest(doFetch, {
    manual: true,
    onSuccess: (res, params) => {
      if (res?.code == '0000') {
        actionRef?.current?.reload();
        setdrawer((s) => ({
          ...s,
          open: false,
        }));
      }
    },
  });
  const rightExtra = (text, row, _, action) => {
    //1未开始  2进行中  3已到期  4待押金退还
    let ifs = row.status == 1,
      ifsa = row.status == 2,
      ifsb = row.status == 3,
      ifsc = row.status == 4;

    return [
      ifs && <PremButton
        key='start'
        btn={{
          size: 'small',
          onClick: () => {
            setdrawer((s) => ({
              ...s,
              open: true,
              item: row,
              val: 'start',
              title: '开始',
              fields: [
                {
                  title: '合同起租日',
                  dataIndex: 'startLeaseDate',
                  key: 'startLeaseDate',
                  valueType: 'date',
                  formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
                  colProps: { span: 8 },
                },
                {
                  title: '合同终止日',
                  dataIndex: 'endLeaseDate',
                  key: 'endLeaseDate',
                  valueType: 'date',
                  fieldProps: {
                    disabled: true
                  },
                  colProps: { span: 8 },
                  formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
                },
                {
                  title: '第一期回款形式',
                  dataIndex: 'tripBear',
                  key: 'tripBear',
                  valueType: 'select',
                  options: [
                    { label: '现金', value: 1 },
                    { label: '银行承兑', value: 2 },
                  ],
                  colProps: { span: 8 },
                  formItemProps: { rules: [{ required: true, message: '此项为必填项' }] },
                },
                {
                  title: '租赁设备',
                  dataIndex: 'list',
                  key: 'list',
                  render: (_, row) => {
                    return <div>11</div>
                  }
                },
                {
                  title: '起租单上传',
                  dataIndex: 'startLeaseFileList',
                  key: 'startLeaseFileList',
                  valueType: 'uploadBtn',
                  fieldProps: {
                    limit: 1,
                  },
                  colProps: { span: 24 },
                },
                {
                  title: '发用单文件',
                  dataIndex: 'hairuseFileList',
                  key: 'hairuseFileList',
                  valueType: 'uploadBtn',
                  fieldProps: {
                    limit: 1,
                  },
                  colProps: { span: 24 },
                },
                {
                  title: '租赁物交付确认单文件',
                  dataIndex: 'leaseDeliverFileList',
                  key: 'leaseDeliverFileList',
                  valueType: 'uploadBtn',
                  fieldProps: {
                    limit: 1,
                  },
                  colProps: { span: 24 },
                }
              ]
            }));
          },
        }}
      >
        开始
      </PremButton>,
      ifs && <PremButton
        key='edit'
        btn={{
          size: 'small',
          onClick: () => {
            setdrawer((s) => ({
              ...s,
              open: true,
              item: row,
              val: 'edit',
              title: '编辑'
            }));
          },
        }}
      >
        修改
      </PremButton>,
      ifs && <PremButton
        key='remove'
        pop={{
          title: '是否删除该合同?',
          okText: '确认',
          cancelText: '取消',
          onConfirm: async () => {
            runAsync({ url: pathconfig.delete, params: { id: row.id, } });
          },
        }}
        btn={{
          size: 'small',
          type: 'danger',
        }}
      >
        删除
      </PremButton>,
      ifsa && <PremButton
        key='out'
        btn={{
          size: 'small',
          onClick: () => {

          },
        }}
      >
        退租
      </PremButton>,
      ifsb && <PremButton
        key='break'
        btn={{
          size: 'small',
          onClick: () => {

          },
        }}
      >
        结束
      </PremButton>,
      ifsc && <PremButton
        key='handle'
        btn={{
          size: 'small',
          onClick: () => {

          },
        }}
      >
        处理
      </PremButton>
    ]
  }

  const columns = useMemo(() => {
    let defcolumn = getcolumns(setdrawer).filter((it) => it.key == activeTabKey)[0]?.columns;
    let defpath = getcolumns(setdrawer).filter((it) => it.key == activeTabKey)[0]?.pathconfig ?? {};
    if (activeTabKey == 1) {
      return defcolumn.concat({
        title: '操作',
        valueType: 'option',
        width: 150,
        render: (text, row, _, action) => rightExtra(text, row, _, action),
      });
    } else {
      return defcolumn;
    }
  }, [activeTabKey]);

  const pathconfig = useMemo(() => {
    let defpath = getcolumns(setdrawer).filter((it) => it.key == activeTabKey)[0]?.pathconfig ?? {};
    return defpath;
  }, [activeTabKey]);
  const calculateContractAmount = (list = [], month = 0) => {
    const sum = list?.reduce((prev, next) => {
      if (Number(prev + next)) {
        return Number((prev + next).toFixed(2));
      }
    }, 0);
    camount(month == 0 || month ? ((sum ?? 0) * 100) * month / 100 : 0);
  };
  const changeList = (list = []) => {
    list.forEach(it => {
      if (it.unitPrice && it.zxPrice) {
        it.rebatePrice = Number(((it.unitPrice ?? 0) - (it.zxPrice ?? 0)).toFixed(2))
      } else {
        it.rebatePrice = ''
      }
    });
    return list;
  };
  return (
    <div style={{ position: 'relative' }}>
      <AutoTable
        pagetitle={<h3 className="page-title">租赁合同</h3>}
        columns={columns}
        path={pathconfig?.list}
        actionRef={actionRef}
        pageextra={pathconfig?.enableadd ? 'add' : null}
        resizeable={false}
        addconfig={{
          // access: 'sysDepartment_save',
          name: '新增',
          btn: {
            disabled: false,
            type: 'primary',
            onClick: () => {
              setdrawer((s) => ({
                ...s,
                open: true,
                item: {
                  registrationDate: dayjs().format('YYYY-MM-DD'),
                  contractEquipmentList: [
                    {
                      equipmentId: '',
                      unitPrice: '',
                      zxPrice: '',
                      rebatePrice: '',
                      deposit: '',
                      remark: ''
                    }
                  ]
                },
                title: '新增',
                val: 'add'
              }));
            },
          },
        }}
        tabList={getcolumns()}
        activeTabKey={activeTabKey}
        onTabChange={(key) => {
          setactiveTabKey(key);
        }}
      />
      <DrawerPro
        fields={(drawer.val != 'add' && drawer.val != 'edit') ? drawer.fields : columns}
        detailpath={pathconfig?.detail || null}
        detailData={drawer?.item}
        defaultFormValue={drawer?.item}
        params={{ id: drawer?.item?.id }}
        formRef={formRef}
        placement="right"
        onClose={() => {
          setdrawer((s) => ({
            ...s,
            open: false,
          }));
        }}
        {...drawer}
        onFinish={(vals) => {
          console.log(vals);
          if (drawer?.val == 'add') {
            run({ url: pathconfig?.add, params: { ...vals, amount } });
          } else if (drawer?.val == 'edit') {
            run({ url: pathconfig?.edit, params: { ...vals, id: drawer?.item?.id, amount } });
          }
        }}
        onValuesChange={(changedValues, allValues) => {
          for (let i in changedValues) {
            if (i == 'contractEquipmentList' || i == 'tenancy') {
              calculateContractAmount(allValues['contractEquipmentList']?.map(it => it.unitPrice ?? 0), allValues['tenancy']);
            }
            if (i == 'contractEquipmentList') {
              let newList = changeList(allValues['contractEquipmentList']);
              formRef?.current?.setFieldsValue({ ['contractEquipmentList']: newList });
              setdrawer((s) => {
                return {
                  ...s,
                  item: { ...s.item, contractEquipmentList: newList }
                }
              })
            }
          }
        }}
        submitter={{
          render: (props, doms) => {
            return [
              <div key='render' className='spread' style={{ position: 'fixed', bottom: 12, width: 'calc(100% - 62px)' }}>
                <div key='amount' style={{ color: 'red', fontSize: 16, fontWeight: 500 }}>
                  <span>合同金额（单位：元）：</span>
                  <span>{amount}</span>
                </div>,
                <div>
                  <PremButton
                    key='rest'
                    btn={{
                      onClick: () => {
                        props.form?.resetFields()
                      },
                      style: { marginRight: 8 }
                    }}
                  >
                    重置
                  </PremButton>,
                  <PremButton
                    key='submit'
                    btn={{
                      type: "primary",
                      onClick: () => {
                        props.form?.submit?.()
                      },
                    }}
                  >
                    提交
                  </PremButton>,
                </div>
              </div>
            ];
          },

        }}
      >
        {/* {selectType(drawer?.val)} */}
      </DrawerPro>
    </div>
  );
}

export default Contract;
